.. _aerospike_operation_helpers.batch:

aerospike\_helpers\.batch package
=================================

aerospike\_helpers\.batch\.records module
-----------------------------------------

Classes for the use with client batch APIs :meth:`~Client.batch_write`, :meth:`~Client.batch_operate`, :meth:`~Client.batch_apply`, :meth:`~Client.batch_remove`.

.. automodule:: aerospike_helpers.batch.records
    :members:
    :show-inheritance:
    :special-members:
